/*
 * DockDemo.cxx z_hossain 22-01-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA.
 *
 */

#include <FL/Fl.H>
#include <FL/Fl_Group.H>
#include <FL/Fl_Window.H>
#include <FL/Fl_Button.H>
#include <FL/Fl_Menu_Bar.H>
#include <FL/Fl_Text_Editor.H>
#include <FL/Fl_Text_Buffer.H>

#include "Fl_Dock_Group.H"
#include "Fl_Toolbar.H"

Fl_Menu_Item menutable[] = {
	{"&File",0,0,0,FL_SUBMENU},
	{"&Open",	FL_ALT+'o', 0, 0, FL_MENU_INACTIVE},
	{"&Close",	0,	0},
	{"&Quit",	FL_ALT+'q', 0, 0, FL_MENU_DIVIDER},
	{"&submenu",FL_CTRL+'S',	0, (void*)"submenu2", FL_SUBMENU},
	{"item 1"},
	{"item 2"},
	{"item 3"},
	{"item 4"},
	{0},
	{"after submenu"},
	{0},
	{"&Edit",FL_F+2,0,0,FL_SUBMENU},
	{"Undo",	FL_ALT+'z',	0},
	{"Redo",	FL_ALT+'r',	0, 0, FL_MENU_DIVIDER},
	{"Cut",	FL_ALT+'x',	0},
	{"Copy",	FL_ALT+'c',	0},
	{"Paste",	FL_ALT+'v',	0},
	{"Inactive",FL_ALT+'d',	0, 0, FL_MENU_INACTIVE},
	{"Clear",	0,	0, 0, FL_MENU_DIVIDER},
	{"Invisible",FL_ALT+'e',	0, 0, FL_MENU_INVISIBLE},
	{"Preferences",0,	0},
	{"Size",	0,	0},
	{0},
	{"&Font",0,0,0,FL_SUBMENU},
	{"Normal",	0, 0, 0, 0, 0, 0, 14},
	{"Bold",	0, 0, 0, 0, 0, FL_BOLD, 14},
	{"Italic",	0, 0, 0, 0, 0, FL_ITALIC, 14},
	{"BoldItalic",0,0,0, 0, 0, FL_BOLD+FL_ITALIC, 14},
	{"Small",	0, 0, 0, 0, 0, FL_BOLD+FL_ITALIC, 10},
	{"Emboss",	0, 0, 0, 0, FL_EMBOSSED_LABEL},
	{"Engrave",	0, 0, 0, 0, FL_ENGRAVED_LABEL},
	{"Shadow",	0, 0, 0, 0, FL_SHADOW_LABEL},
	{"@->",	0, 0, 0, 0, FL_SYMBOL_LABEL},
	{0}
};


int main(int argc, char **argv) {

	Fl_Window *win = new Fl_Window(550, 550, "Dock Demo");
	win->begin();
	Fl_Menu_Bar menubar(0,0,win->w(),30);
	menubar.menu(menutable);

	Fl_Dock_Group *dg = new Fl_Dock_Group(0, 30, win->w(), win->h() - 30);
	dg->begin();
	Fl_Text_Editor *td = new Fl_Text_Editor(dg->x(), dg->y(), dg->w(), dg->h());
	dg->widget(td);
	dg->end();
	Fl_Text_Buffer *textbuf = new Fl_Text_Buffer();
	td->buffer(textbuf);

	win->end();
	win->resizable(dg);

	Fl_Toolbar *dw = new Fl_Toolbar(20, 20, 200, 50, "Tool");
	dw->end();
	dw->add_button("one");
	dw->add_button("two");
	dw->add_button("three");
	dw->add_button("four");
	dw->dock_group(dg);


	win->show(argc, argv);
	dw->show();

	return Fl::run();
}
