/*
 * Fl_Toolbar.cxx z_hossain 22-01-2006
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA.
 *
 */

#include <FL/Fl.H>
#include <FL/fl_draw.H>
#include <FL/Fl_Button.H>
#include <FL/fl_draw.H>
#include <string.h>
#include <stdio.h>

#include "Fl_Toolbar.H"


void drag_menu_cb(Fl_Widget* w, void* t) {
	((Fl_Toolbar *)t)->cb_menu();
}

void Fl_Toolbar::cb_menu() {
	const Fl_Menu_Item* m = drag_->mvalue();
	int index = m - drag_->menu()->first();

	if(index >= 0 && index <= 3) {
		hide();
		dock_group_->add(this);
		switch(index) {
			case 0:
				if(orientation_ != FL_ORIENTATION_VERTICAL) {
					orientation_ = FL_ORIENTATION_VERTICAL;
					resize(x(), y(), h(), w());
				}
				dock_group_->dock(this, FL_ALIGN_LEFT);
				break;
			case 1:
				if(orientation_ != FL_ORIENTATION_VERTICAL) {
					orientation_ = FL_ORIENTATION_VERTICAL;
					resize(x(), y(), h(), w());
				}
				dock_group_->dock(this, FL_ALIGN_RIGHT);
				break;
			case 2:
				if(orientation_ != FL_ORIENTATION_HORIZONTAL) {
					orientation_ = FL_ORIENTATION_HORIZONTAL;
					resize(x(), y(), h(), w());
				}
				dock_group_->dock(this, FL_ALIGN_TOP);
				break;
			case 3:
				if(orientation_ != FL_ORIENTATION_HORIZONTAL) {
					orientation_ = FL_ORIENTATION_HORIZONTAL;
					resize(x(), y(), h(), w());
				}
				dock_group_->dock(this, FL_ALIGN_BOTTOM);
				break;
		}
		state_ = FL_STATE_DOCKED;
		show();
	}
	else if(index >= 4 && index <= 5 && orientation_ != index - 4){   //depend on menu index
		orientation_ = index - 4;
		resize(x(), y(), h(), w());
	}
	else if(index == 6){
		hide();
		dock_group_->remove(this);
		parent(0);
		show();
		state_ = FL_STATE_UNDOCKED;
		dock_group_->undock(this);
	}
	else if(index == 7) {
		hide();
	}
}

Fl_Drag_Button::Fl_Drag_Button(Fl_Widget *w) : Fl_Menu_Button(5, 5, 8, w->h() - 10) {
	down_box(FL_UP_BOX);
}

void Fl_Drag_Button::draw() {
	draw_box(FL_ROUND_UP_BOX, x(), y(), w(), h(), color());
}

int Fl_Drag_Button::handle(int e) {
	switch (e) {
		case FL_PUSH:
			if(Fl::event_button() == FL_RIGHT_MOUSE) {
				popup();
			}	
	}
	return 1;
}

Fl_Toolbar::Fl_Toolbar(int X, int Y, int W, int H,const char *l) 
: Fl_Window(X, Y, W, H, l) {
	clear_border();
	box(FL_UP_BOX);

	static Fl_Menu_Item drag_menu[] = {
		{"Dock Left"},
		{"Dock Right"},
		{"Dock Top"},
		{"Dock Bottom"},
		{"Vertical"},
		{"Horizontal"},
		{"Float"},
		{"Hide"},
		{0}
	};
	drag_ = new Fl_Drag_Button(this);
	drag_->menu(drag_menu);
	drag_->callback((Fl_Callback *)drag_menu_cb, (void *)this);

	state_ = FL_STATE_UNDOCKED;
	orientation_ = FL_ORIENTATION_HORIZONTAL;
}

void Fl_Toolbar::draw() {
	int spacing_ = 2;

	int tx, ty;
	if(orientation_) {
		tx = 15 + Fl::box_dx(box());
		ty = Fl::box_dy(box());
	}
	else {
		tx = Fl::box_dx(box());
		ty = 15 + Fl::box_dy(box());
	}
	int tw = w() - Fl::box_dw(box());
	int th = h() - Fl::box_dh(box());

	int current_position = (orientation_? tx : ty) + spacing_ / 2;
	int maximum_position = current_position;
	uchar d = damage();

	draw_box(FL_UP_BOX, 0, 0, w(), h(), color());
	Fl_Widget*const* a = array() + 1;

	for (int i = children() - 1; i --; ) {
		Fl_Widget* o = *a++;
		if (o->visible()) {
			int X,Y,W,H;
			if (orientation_) {
				X = current_position;
				W = o->w();
				Y = ty;
				H = th;
			} else {
				X = tx;
				W = tw;
				Y = current_position;
				H = o->h();
			}
			if (spacing_ && current_position>maximum_position && box() &&
				(X != o->x() || Y != o->y() || d&FL_DAMAGE_ALL)) {
				fl_color(color());
				if (orientation_)
					fl_rectf(maximum_position, ty, spacing_, th);
				else
					fl_rectf(tx, maximum_position, tw, spacing_);
			}
			if (X != o->x() || Y != o->y() || W != o->w() || H != o->h()) {
				o->resize(X,Y,W,H);
				o->clear_damage(FL_DAMAGE_ALL);
			}
			current_position += (orientation_ ? o->w() : o->h());
			if (current_position > maximum_position)
				maximum_position = current_position;
			current_position += spacing_;

			draw_child(*o);
			draw_outside_label(*o);
		}
	}

	if (orientation_) {
		resize(x(), y(), maximum_position + Fl::box_dw(box()), th + Fl::box_dh(box()));
	} 
	else {
		resize(x(), y(), tw + Fl::box_dw(box()), maximum_position + Fl::box_dh(box()));
	}

	if(orientation_) {
		drag_->resize(5, 5, 8, h() - 10);
		draw_child(*drag_);
	}
	else {
		drag_->resize(5, 5, w() - 10, 8);
		draw_child(*drag_);
	}
}

int Fl_Toolbar::handle(int event) {
	static int oldx_, oldy_, flag_;

	switch(event) {
		case FL_PUSH:
			if(Fl::event_inside(drag_) && Fl::event_button() == FL_LEFT_MOUSE) {
				oldx_ = Fl::event_x();
				oldy_ = Fl::event_y();
				flag_ = 1;
				return 1;
			}
			break;
		case FL_RELEASE:
			flag_ = 0;
			break;
		case FL_DRAG:
			if(flag_ && state_ == FL_STATE_UNDOCKED) {
				this->position(x() + Fl::event_x() - oldx_, y() + Fl::event_y() - oldy_);
				return 1;
			}
			break;
	}
	return Fl_Window::handle(event);
}

Fl_Tool_Button *Fl_Toolbar::add_button(const char *s) {
	Fl_Tool_Button *bt = new Fl_Tool_Button(s);
	add(bt);
	return bt;
}

Fl_Toolbar::~Fl_Toolbar() {
}
